@@ -164,7 +164,7 @@ bool AktionPart::closeURL()
 }
 
 void AktionPart::slotPlay()
-{
+{    
     widget->play();
     m_playAction->setEnabled(false);
     m_pauseAction->setEnabled(true);
@@ -185,7 +185,8 @@ void AktionPart::slotPause()
 
 void AktionPart::slotStop()
 {
-    widget->stop();
+    if (!widget.isNull()) //Could be already destroyed, if we were called from dtor.
+        widget->stop();
     m_playAction->setEnabled(true);
     m_pauseAction->setEnabled(false);
     m_stopAction->setEnabled(false);
