@@ -26,6 +26,8 @@
 #include <unistd.h>
 #include <arts/debug.h>
 
+#include <kdebug.h>
+
 #ifndef HAVE_LIBPTHREAD
 #define pthread_create(a, b, c, d) ;
 #define pthread_join(a, b) ;
@@ -57,6 +59,14 @@ bool ARCommand::isDestructive()
 AutoRouter::AutoRouter(int width, int height)
 	: width(width), height(height)
 {
+#ifdef HAVE_LIBPTHREAD
+	pthread_attr_t attrs;
+
+	pthread_attr_init(&attrs);
+	pthread_mutex_init(&mutex_sync, 0);
+	pthread_mutex_init(&mutex_queue, 0);
+#endif
+
 	// allocate memory for fields..
 	field = new Field*[width];
 	completeField = new Field*[width];
@@ -88,12 +98,6 @@ AutoRouter::AutoRouter(int width, int height)
 	
 	thread_terminate_now = false; 		// not yet
 #ifdef HAVE_LIBPTHREAD
-	pthread_attr_t attrs;
-
-	pthread_attr_init(&attrs);
-	pthread_mutex_init(&mutex_sync, 0);
-	pthread_mutex_init(&mutex_queue, 0);
-
 	// setup thread and run thread_command_loop() in it
 	pthread_create(&route_thread, &attrs, startroute, this);
 #endif
@@ -160,13 +164,11 @@ void AutoRouter::enqueue(ARCommand *command)
 		// ok, then we can kill the whole list, since this will clear
 		// the whole results anyway
 
-		while(command_queue.size() > 0)
-		{
-			delete *command_queue.begin();
-			command_queue.pop_front();
-		}
+		command_queue.setAutoDelete(true);
+		command_queue.clear();
+		command_queue.setAutoDelete(false);
 	}
-	command_queue.push_back(command);
+	command_queue.append(command);
 	
 	pthread_mutex_unlock(&mutex_queue);
 #else
@@ -184,14 +186,17 @@ void AutoRouter::thread_command_loop()
 
 		// pop one command from queue if possible..
 		pthread_mutex_lock(&mutex_queue);
-		if(command_queue.size() > 0)
+		if(!command_queue.isEmpty())
 		{
-			command = (*command_queue.begin());
-			command_queue.pop_front();
+			command = command_queue.first();
+			command_queue.remove(unsigned(0));
 		}
 		else
 		{
-			if(thread_terminate_now) return;
+			if (thread_terminate_now) {
+				pthread_mutex_unlock(&mutex_queue);
+				return;
+			}
 		}
 		pthread_mutex_unlock(&mutex_queue);
 
@@ -419,8 +424,9 @@ void AutoRouter::thread_connect(int x1, int y1, int x2, int y2, long owner)
 		PathQueue& activePathList =
 			pathlist[activelist];
 
-		examinePath(activePathList.top());
-		activePathList.pop();
+		assert(activePathList.size());
+		examinePath(activePathList.first());
+		activePathList.pop_front();
 		numQueuedPaths--;
 	}
 
@@ -432,7 +438,7 @@ void AutoRouter::thread_connect(int x1, int y1, int x2, int y2, long owner)
 		//arts_debug("bestGoalPath.history for this connection is %s", bestGoalPath.history.data());
 		//arts_debug("minCost for that was %d", gms);
 
-		const char *walk = bestGoalPath.history.c_str();
+		const char *walk = bestGoalPath.history.ascii();
 
 		int x = x1;
 		int y = y1;
@@ -479,14 +485,15 @@ void AutoRouter::queuePath(const PathInfo &path)
 	if(targetlist > 1023)
 		targetlist = 1023;
 
-	pathlist[targetlist].push(newPath);
+	pathlist[targetlist].append(newPath);
+	qHeapSort(pathlist[targetlist]);
 
 	numQueuedPaths++;
 }
 
 void AutoRouter::examinePath(const PathInfo &path)
 {
-	const char *walk = path.history.c_str();
+	const char *walk = path.history.ascii();
 
 // check if we can go here:
 
