@@ -79,7 +79,7 @@ char *DirManager::directory(const char *subdir, const QString &desc)
 			"It will be used to store %2.\nShould I create it now?")
 			.arg(dirname.c_str()).arg(desc);
 
-		if(KMessageBox::questionYesNo(0,message,i18n("aRts directory missing"))
+		if(KMessageBox::questionYesNo(0,message,i18n("aRts Directory Missing"))
 			== KMessageBox::Yes)
 		{
 			char command[1024];
