@@ -5,7 +5,20 @@
 
 using namespace std;
 
-MenuCategory::MenuCategory(const char *name, const char *prefix,QPopupMenu *menu)
+MenuEntry::MenuEntry(MenuMaker *menumaker, KActionMenu *parent, const char *text)
+	: menumaker(menumaker), text(text)
+{
+	action = new KAction(QString::fromLocal8Bit(text));
+	parent->insert(action);
+	connect(action, SIGNAL(activated()), this, SLOT(activated()));
+}
+
+void MenuEntry::activated()
+{
+	menumaker->menuActivated(text);
+}
+
+MenuCategory::MenuCategory(const QString& name, const char *prefix, KActionMenu *menu)
 {
 	_menu = menu;
 	_name = name;
@@ -13,9 +26,9 @@ MenuCategory::MenuCategory(const char *name, const char *prefix,QPopupMenu *menu
 	addPrefix(prefix);
 }
 
-const char *MenuCategory::name()
+QString MenuCategory::name()
 {
-	return _name.c_str();
+	return _name;
 }
 
 bool MenuCategory::catchall()
@@ -47,12 +60,12 @@ bool MenuCategory::matches(const char *item)
 	return false;
 }
 
-QPopupMenu *MenuCategory::menu()
+KActionMenu *MenuCategory::menu()
 {
 	return _menu;
 }
 
-MenuMaker::MenuMaker(QPopupMenu *root)
+MenuMaker::MenuMaker(KActionMenu *root)
 {
 	categories.push_back(new MenuCategory("","",root));
 }
@@ -63,7 +76,7 @@ MenuMaker::MenuMaker(QPopupMenu *root)
 //  addCategory("&Synthesis", "Synth_");
 //  addCategory("&Synthesis/&Waveforms", "Synth_WAVE");
 
-void MenuMaker::addCategory(const char *name, const char *prefix)
+void MenuMaker::addCategory(const QString& name, const char *prefix)
 {
 	MenuCategory *mc = 0,*pc = 0;
 	
@@ -74,28 +87,32 @@ void MenuMaker::addCategory(const char *name, const char *prefix)
 		return; // already exists
 	}
 
-	pc = lookupCategoryByName(basename(name).c_str());
+	pc = lookupCategoryByName(basename(name));
 	if(pc)
 	{
-		QPopupMenu *newMenu = new QPopupMenu;
-		connect(newMenu,SIGNAL(activated(int)),this,SLOT(menuactivated(int)));
-		pc->menu()->insertItem(catname(name).c_str(), newMenu, CAT_MAGIC_ID);
-		arts_debug("inserting a menu called '%s' in the parent menu '%s'",catname(name).c_str(),pc->name());
+		KActionMenu *newMenu = new KActionMenu(catname(name));
+		pc->menu()->insert(newMenu);
+		/* 000 */
+		/*connect(newMenu,SIGNAL(activated(int)),this,SLOT(menuactivated(int)));
+		pc->menu()->insertItem(catname(name).c_str(), newMenu, CAT_MAGIC_ID);*/
+		arts_debug("inserting a menu called '%s' in the parent menu '%s'",
+			catname(name).local8Bit().data(),pc->name().local8Bit().data());
 		categories.push_back(new MenuCategory(name,prefix,newMenu));
 	}
 	else
 	{
-		arts_debug("Parent category '%s' for '%s' is missing.",basename(name).c_str(),name);
+		arts_debug("Parent category '%s' for '%s' is missing.",
+				basename(name).local8Bit().data(),name.local8Bit().data());
 	}
 }
 
-MenuCategory *MenuMaker::lookupCategoryByName(const char *name)
+MenuCategory *MenuMaker::lookupCategoryByName(const QString& name)
 {
 	MenuCategory *mc = 0;
 	list<MenuCategory *>::iterator i;
 	for(i=categories.begin();i != categories.end();i++)
 	{
-		if(strcmp((*i)->name(),name) == 0) mc = (*i);
+		if((*i)->name() == name) mc = (*i);
 	}
 	return mc;
 }
@@ -109,45 +126,44 @@ void MenuMaker::addItem(const char *name, int index)
 		if((*i)->matches(name)) mc = (*i);
 	assert(mc);		// root category should always match
 
-	if(!strlen(mc->name()))
+	if(mc->name().isEmpty())
 	{
 		// if we hit the root category, it may be better to move the thing
 		// into the catchall category (looks cleaner)
 		for(i=categories.begin();i != categories.end();i++)
 			if((*i)->catchall()) mc = (*i);
 	}
-	mc->menu()->insertItem(name,index);
+	//mc->menu()->insertItem(name,index); 000
+	//mc->menu()->insert(new KAction(name)); // index??
+	new MenuEntry(this, mc->menu(), name);
+	/*
+	KAction *action = new KAction(QString(name));
+	mc->menu()->insert(action);
+	*/
+	//action->plug(mc->menu());
+	//mc->menu()->insert(new KAction(name)); // index??
 }
 
-string MenuMaker::basename(const char *name)
+QString MenuMaker::basename(const QString& name)
 {
-	char *x = strdup(name);
-	int i;
+	QString result = "";
 
-	i=strlen(x)-1;
-	while(i>=0)
-	{
-		if(x[i] == '/')
-		{
-			x[i]=0;
-			i = -2;
-		}
-		else i--;
-	}
-	if(i != -2) x[0] = 0; // no slash means empty parent category
-	string result(x);
-	free(x);
-	arts_debug("basename(%s) => %s",name,result.c_str());
+	int i = name.findRev('/');
+	if(i != -1)
+		result = name.left(i);
+
+	arts_debug("basename(%s) => %s",name.local8Bit().data(),
+									result.local8Bit().data());
 	return result;
 }
 
-string MenuMaker::catname(const char *name)
+QString MenuMaker::catname(const QString& name)
 {
-	int i;
-	for(i=strlen(name)-1;i>=0;i--)
-		if(name[i] == '/') return string(&name[i+1]);
+	int i = name.findRev('/');
+	if(i >= 0)
+		return name.mid(i+1);
 
-	return string(name);
+	return name;
 }
 
 void MenuMaker::clear()
@@ -155,7 +171,8 @@ void MenuMaker::clear()
 	list<MenuCategory *>::iterator i;
 	for(i=categories.begin();i != categories.end();i++)
 	{
-		QPopupMenu *m = (*i)->menu();
+		/* 000
+		KActionMenu *m = (*i)->menu();
 		unsigned int k;
 
 		k = 0;
@@ -171,22 +188,25 @@ void MenuMaker::clear()
 				k++;
 			}
 		}
+		*/
 	}
 }
 
 const char *MenuMaker::findID(int id)
 {
+	/* 000 ?
 	list<MenuCategory *>::iterator i;
 	for(i=categories.begin();i != categories.end();i++)
 	{
 		const char *name = (*i)->menu()->text(id);
 		if(name) return(name);
-	}
+	} */
 	return 0;
 }
 
-void MenuMaker::menuactivated(int i)
+void MenuMaker::menuActivated(const char *text)
 {
-	emit activated(i);
+	emit activated(text);
 }
 
+#include "menumaker.moc"
