@@ -27,7 +27,7 @@
 #include <qdialog.h>
 #include <qlistbox.h>
 #include <qlabel.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <vector>
 
 class PortPosDlg :public QDialog {
