@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <iostream>
 #include <fstream>
+#include <kdebug.h>
 #include <arts/debug.h>
 
 using namespace std;
@@ -131,6 +132,10 @@ bool Structure::startExecute()
 	
 	/* create the structure on the server */
 	structure = Arts::DynamicCast(builder.createObject(remoteSD));
+
+	if (structure.isNull())
+		return false;
+
 	structure.start();
 
 	return true;
