@@ -20,14 +20,28 @@
 */
 
 #include "klineedit_impl.h"
+#include "klineedit_impl.moc"
 
 using namespace Arts;
 using namespace std;
 
+KLineEditStringMapper::KLineEditStringMapper(KLineEdit_impl *impl, KLineEdit *ke)
+	:impl(impl)
+{
+	connect(ke, SIGNAL(textChanged(const QString&)),
+			this, SLOT(textChanged(const QString&)));
+}
+
+void KLineEditStringMapper::textChanged(const QString& newText)
+{
+	impl->textChanged(newText.utf8().data());
+}
+
 KLineEdit_impl::KLineEdit_impl(KLineEdit *le)
 	: KWidget_impl(le ? le : new KLineEdit(0))
 {
 	this->klineedit = static_cast<KLineEdit*>(qwidget);
+	new KLineEditStringMapper(this, this->klineedit);
 }
 
 string KLineEdit_impl::text()
@@ -40,6 +54,11 @@ void KLineEdit_impl::text(const string& newText)
 	klineedit->setText(QString::fromUtf8(newText.c_str()));
 }
 
+void KLineEdit_impl::textChanged(const string& newText)
+{
+	text_changed(newText);
+}
+
 string KLineEdit_impl::caption()
 {
 	return ""; // FIXME
