@@ -25,23 +25,37 @@
 
 using namespace Arts;
 
+namespace Arts {
+
+#define NOISE_SIZE 8192
+
 class Synth_NOISE_impl : virtual public Synth_NOISE_skel,
 							virtual public StdSynthModule
 {
-	float noise[4096];
+	static float noise[NOISE_SIZE];
+	static bool noiseInit;
 	unsigned long pos;
 public:
-	void streamInit()
+	Synth_NOISE_impl()
 	{
-		for(unsigned long i=0;i<4096;i++)
-			noise[i] = ((float)rand()/(float)RAND_MAX)*2.0-1.0;
-		pos = 0;
+		if(!noiseInit)
+		{
+			for(unsigned long i=0;i<NOISE_SIZE;i++)
+				noise[i] = ((float)rand()/(float)RAND_MAX)*2.0-1.0;
+			noiseInit = true;
+		}
 	}
 	void calculateBlock(unsigned long samples)
 	{
 		unsigned long i;
-		for(i=0;i<samples;i++) outvalue[i] = noise[pos++ & 4095];
+		pos = rand();
+		for(i=0;i<samples;i++) outvalue[i] = noise[pos++ & (NOISE_SIZE-1)];
 	}
 };
 
+float Synth_NOISE_impl::noise[8192];
+bool Synth_NOISE_impl::noiseInit = false;
+
 REGISTER_IMPLEMENTATION(Synth_NOISE_impl);
+
+}
