@@ -205,7 +205,7 @@ ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server)
 							i18n("Artsd is not configured for realtime scheduling\n "
 								 "or was manually started without artswrapper."):
 							i18n("Artsd should run with realtime scheduling,\n but it "
-								 "does not (is artswrapper suid root?)."),
+								 "does not (Is artswrapper suid root?)."),
 							this, "realtimeLabel"));
 	l->addSpacing(10);
 
@@ -471,7 +471,7 @@ MainWindow::MainWindow() : KMainWindow(0)
 		SLOT(showAudioManager()), actionCollection(), "view_audio_manager");
 	(void)new KAction(i18n("View aRts &Status"), 0, vc,
 		SLOT(showArtsStatusView()), actionCollection(), "view_arts_statusview");
-	(void)new KAction(i18n("View &Midi Manager"), 0, vc,
+	(void)new KAction(i18n("View &MIDI Manager"), 0, vc,
 		SLOT(showMidiManager()), actionCollection(), "view_midi_manager");
 	(void)new KAction(i18n("View &Environment"), 0, vc,
 		SLOT(showEnvironment()), actionCollection(), "view_environment");
@@ -480,7 +480,7 @@ MainWindow::MainWindow() : KMainWindow(0)
 	(void)new KAction(i18n("Free&Verb"), 0, vc,
 		SLOT(showFreeVerbView()), actionCollection(), "view_freeverb");
 	showOldVolumeDisplay=
-		new KToggleAction(i18n("&Leds-like volume display"), 0, this,
+		new KToggleAction(i18n("&LED-Style Volume Display"), 0, this,
 		SLOT(toggleVolumeBar()), actionCollection(), "old_volume_display");
 
 	createGUI("artscontrol.rc");
@@ -505,5 +505,6 @@ int main(int argc, char **argv)
 	ObjectManager::the()->provideCapability("kdegui");
 
 	app.setMainWidget(new MainWindow);
+	app.setName("artsbuilder");
 	return app.exec();
 }
