@@ -16,7 +16,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_mp3.cpp,v 1.49.2.2 2002/12/16 15:11:14 lunakl Exp $
+ *  $Id: kfile_mp3.cpp,v 1.49.2.3 2003/09/08 22:57:23 mueller Exp $
  */
 
 #include "kfile_mp3.h"
@@ -42,7 +42,7 @@ extern "C" {
 
 typedef KGenericFactory<KMp3Plugin> Mp3Factory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_mp3, Mp3Factory( "kfile_mp3" ));
+K_EXPORT_COMPONENT_FACTORY(kfile_mp3, Mp3Factory( "kfile_mp3" ))
 
 KMp3Plugin::KMp3Plugin(QObject *parent, const char *name,
                        const QStringList &args)
