@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
@@ -93,7 +93,6 @@ public:
     KDisplayText(QWidget *parent,const char *name);
     virtual ~KDisplayText();
     
-    void PreDestroyer(void);
     void ClearEv(bool totally=true);
     void AddEv(SpecialEvent *ev);
     void calculatePositions(void);
