@@ -2,21 +2,22 @@
 #define __KMIDPART_H__
 
 #include <kparts/browserextension.h>
-#include <klibloader.h>
+#include <kparts/factory.h>
 
 class KAboutData;
 class KInstance;
 class KMidBrowserExtension;
 class kmidClient;
 
-class KMidFactory : public KLibFactory
+class KMidFactory : public KParts::Factory
 {
   Q_OBJECT
   public:
     KMidFactory();
     virtual ~KMidFactory();
 
-    virtual QObject* create(QObject* parent = 0, const char* name = 0,
+    virtual KParts::Part* createPartObject(QWidget *parentWidget, const char *widgetName,
+                QObject* parent = 0, const char* name = 0,
                 const char* classname = "QObject",
                 const QStringList &args = QStringList());
 
@@ -31,7 +32,8 @@ class KMidPart: public KParts::ReadOnlyPart
 {
   Q_OBJECT
   public:
-    KMidPart(QWidget *parent, const char *name);
+    KMidPart(QWidget *parentWidget, const char *widgetName, 
+             QObject *parent, const char *name);
     virtual ~KMidPart();
 
 
