@@ -67,8 +67,10 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     :QWidget(parent,name), DCOPObject("KMidIface")
 {
     actionCollection=ac;
+    KConfig *cfg=kapp->config();
+    cfg->setGroup("KMid");
     midifile_opened=0L;
-    loopsong=0;
+    loopsong=cfg->readNumEntry("Loop",0);
     collectionplaymode=0;	
     collectionplaylist=0L;
     channelView=0L;
@@ -94,7 +96,7 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     timetags = new QSliderTime(timebar,this);
     timetags->setMinimumSize(timetags->sizeHint());
  
-    qlabelTempo= new QLabel(i18n("Tempo :"), this,"tempolabel",
+    qlabelTempo= new QLabel(i18n("Tempo:"), this,"tempolabel",
                             QLabel::NoFrame);
     
     tempoLCD = new KLCDNumber( true, 3, this, "TempoLCD");
@@ -119,12 +121,11 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     volumebar->setValue(100);
     volumebar->setTickmarks(QSlider::NoMarks);
     volumebar->setTickInterval(50);
-    volumebar->hide();
-#ifdef TEMPHACK
-    volumebar->show();
-#endif
-    visiblevolumebar=0;
     connect (volumebar,SIGNAL(valueChanged(int)),this,SLOT(slotSetVolume(int)));
+
+    visiblevolumebar=cfg->readNumEntry("ShowVolumeBar",0);
+    if (visiblevolumebar) volumebar->show();
+    else volumebar->hide();
    
     typeoftextevents=1;
     kdispt=new KDisplayText( this, "KaraokeWindow");
@@ -143,14 +144,14 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     m_kMid.pctlsmID=shmget(IPC_PRIVATE,sizeof(PlayerController),0666 | IPC_CREAT );
     if (m_kMid.pctlsmID==-1)
     {
-        printf("ERROR : Can't allocate shared memory !!!\n"
+        printf("ERROR: Can't allocate shared memory !!!\n"
                "Please report to larrosa@kde.org\n");
 	exit(1);
     }
     
     m_kMid.pctl=(PlayerController *)shmat(m_kMid.pctlsmID,0L,0);
     if (!m_kMid.pctl)
-        printf("ERROR : Can't get shared memory !!! "
+        printf("ERROR: Can't get shared memory !!! "
                "Please report to larrosa@kde.org\n");
     m_kMid.pctl->playing=0;
     m_kMid.pctl->gm=1;
@@ -176,12 +177,9 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     QCString qs=QFile::encodeName(kconf->readEntry("Loadfile","gm.map"));
     
 #ifdef KMidDEBUG
-    printf("Read Config file : %s\n",qs.data());
+    printf("Read Config file: %s\n",qs.data());
 #endif
-    char *tmp=new char[qs.length()+1];
-    strcpy(tmp,qs);
-    setMidiMapFilename(tmp);
-    delete tmp;
+    setMidiMapFilename(qs.data());
     
     initializing_songs=1;
     kconf->setGroup("KMid"); 
@@ -240,8 +238,7 @@ kmidClient::~kmidClient()
     if (midifile_opened) delete midifile_opened;
     delete player;
     delete midi;
-    if (collectionplaylist) delete collectionplaylist;
-    
+    delete [] collectionplaylist;
 
     saveCollections();
     delete slman;
@@ -288,7 +285,7 @@ int kmidClient::openFile(const char *filename)
                             i18n("The file %1 doesn't exist or can't be opened.").arg(filename);
         break;
         case (-2) : errormsg =
-                            i18n("The file %1 is not a midi file.").arg(filename);break;
+                            i18n("The file %1 is not a MIDI file.").arg(filename);break;
         case (-3) : errormsg =
                             i18n("Ticks per quarter note is negative. Please send this file to larrosa@kde.org");break;
         case (-4) : errormsg =
@@ -317,7 +314,7 @@ int kmidClient::openFile(const char *filename)
     midifile_opened=new char[strlen(filename)+1];
     strcpy(midifile_opened,filename);
 #ifdef KMidDEBUG
-    printf("TOTAL TIME : %g milliseconds\n",player->information()->millisecsTotal);
+    printf("TOTAL TIME: %g milliseconds\n",player->information()->millisecsTotal);
 #endif
     //    noteArray=player->parseNotes();
     noteArray=player->noteArray();
@@ -534,7 +531,7 @@ void kmidClient::slotPlay()
     if ((m_kMid.pid=fork())==0)
     {
 #ifdef KMidDEBUG
-        printf("PlayerProcessID : %d\n",getpid());
+        printf("PlayerProcessID: %d\n",getpid());
 #endif
         player->play(0,(void (*)(void))kmidOutput);
 #ifdef KMidDEBUG
@@ -565,7 +562,7 @@ void kmidClient::slotPlay()
     timer4timebar->start(1000);
     
 #ifdef KMidDEBUG
-    printf("PlayerProcess : %d . ParentProcessID : %d\n",m_kMid.pid,getpid());
+    printf("PlayerProcess: %d . ParentProcessID: %d\n",m_kMid.pid,getpid());
     printf("******************************-\n");
 #endif
 }
@@ -626,7 +623,7 @@ void kmidClient::slotSeek(int i)
     
     
 #ifdef KMidDEBUG
-    printf("change Time : %d\n",i);
+    printf("change Time: %d\n",i);
 #endif
 
     timer4events->stop();
@@ -644,7 +641,7 @@ void kmidClient::slotSeek(int i)
     if ((m_kMid.pid=fork())==0)
     {
 #ifdef KMidDEBUG
-        printf("Player_ProcessID : %d\n",getpid());
+        printf("Player_ProcessID: %d\n",getpid());
 #endif
         
         player->play(0,(void (*)(void))kmidOutput);
@@ -683,7 +680,7 @@ void kmidClient::slotSeek(int i)
 void kmidClient::moveEventPointersTo(ulong ms)
 {
 #ifdef KMidDEBUG
-    printf("Move To : %lu\n",ms);
+    printf("Move To: %lu\n",ms);
 #endif
     spev=player->specialEvents();
 
@@ -808,7 +805,7 @@ void kmidClient::slotNextSong()
      while ((r=1+(int) ((double)(currentsl->NumberOfSongs())*rand()/(RAND_MAX+1.0)))==currentsl->getActiveSongID()) ;
      
      #ifdef KMidDEBUG
-     printf("random number :%d\n",r);
+     printf("random number:%d\n",r);
      #endif
      currentsl->setActiveSong(r);
      }
@@ -865,7 +862,7 @@ void kmidClient::slotPause()
         if ((m_kMid.pid=fork())==0)
         {
 #ifdef KMidDEBUG
-            printf("PlayerProcessID : %d\n",getpid());
+            printf("PlayerProcessID: %d\n",getpid());
 #endif
             player->play(0,(void (*)(void))kmidOutput);
 #ifdef KMidDEBUG
@@ -1011,13 +1008,13 @@ void kmidClient::kmidOutput(void)
             strncpy(text,(char *)ev->data,ev->length);
             text[ev->length]=0;
 #ifdef KMidDEBUG
-            printf("%s , played at : %ld\n",text,currentmillisec-beginmillisec);
+            printf("%s , played at: %ld\n",text,currentmillisec-beginmillisec);
 #endif
         }
         else if (ev->d1==ME_SET_TEMPO)
         {
             int tempo=(ev->data[0]<<16)|(ev->data[1]<<8)|(ev->data[2]);
-            //	    printf("Change tempo : %d , %g, played at :%ld\n",tempo,tempoToMetronomeTempo(tempo),currentmillisec-beginmillisec);
+            //	    printf("Change tempo: %d , %g, played at:%ld\n",tempo,tempoToMetronomeTempo(tempo),currentmillisec-beginmillisec);
         }
        
     }
@@ -1067,8 +1064,8 @@ void kmidClient::processSpecialEvent()
             {
                 tempoLCD->display(tempoToMetronomeTempo(spev->tempo));
 #ifdef KMidDEBUG
-                printf("Changing lcd tempo : spev->tempo : %d , ratio : %.9g\n",spev->tempo,m_kMid.pctl->ratioTempo);
-                printf("Result : %g %.9g %d\n",tempoToMetronomeTempo(spev->tempo),tempoToMetronomeTempo(spev->tempo),(int)tempoToMetronomeTempo(spev->tempo));
+                printf("Changing lcd tempo: spev->tempo: %d , ratio: %.9g\n",spev->tempo,m_kMid.pctl->ratioTempo);
+                printf("Result: %g %.9g %d\n",tempoToMetronomeTempo(spev->tempo),tempoToMetronomeTempo(spev->tempo),(int)tempoToMetronomeTempo(spev->tempo));
 #endif
                 currentTempo=tempoLCD->getValue();
                 tempoLCD->setDefaultValue(tempoToMetronomeTempo(spev->tempo)*m_kMid.pctl->ratioTempo);
@@ -1080,7 +1077,7 @@ void kmidClient::processSpecialEvent()
             else if (spev->type==7)
             {
 #ifdef KMidDEBUG
-                printf("Beat : %d/%d\n",spev->num,spev->den);
+                printf("Beat: %d/%d\n",spev->num,spev->den);
 #endif
                 rhythmview->Beat(spev->num);
             }
@@ -1297,8 +1294,8 @@ void kmidClient::setSongLoop(int i)
 
 void kmidClient::generateCPL(void)
 {
-    if (collectionplaylist!=NULL) delete collectionplaylist;
-    collectionplaylist=NULL;
+    delete [] collectionplaylist;
+    collectionplaylist=0;
     
     if (currentsl==NULL) return;
     
@@ -1319,7 +1316,7 @@ void kmidClient::saveCollections(void)
 {
     if (slman==NULL) return;
 #ifdef KMidDEBUG
-    printf("Saving collections in : %s\n",collectionsfile.ascii());
+    printf("Saving collections in: %s\n",collectionsfile.ascii());
 #endif
     slman->saveConfig(collectionsfile.ascii());
 }
@@ -1467,15 +1464,15 @@ void kmidClient::slotSetTempo(double value)
     if (strcmp(s,"1")!=0) tempoLCD->setLCDColor (255,100,100);
     else tempoLCD->setLCDColor (100,255,100);
 #ifdef KMidDEBUG
-    printf("ratio : (%.9g = %g ) tempo now : %g , new tempo %g\n",ratio,ratio,tempoToMetronomeTempo(m_kMid.pctl->tempo),value);
-    printf("OldValue : %g , value %g\n",tempoLCD->getOldValue(),value);
+    printf("ratio: (%.9g = %g ) tempo now: %g , new tempo %g\n",ratio,ratio,tempoToMetronomeTempo(m_kMid.pctl->tempo),value);
+    printf("OldValue: %g , value %g\n",tempoLCD->getOldValue(),value);
 #endif
     
     if (m_kMid.pctl->paused==1)
     {
         pausedatmillisec=(long)(((double)pausedatmillisec/m_kMid.pctl->ratioTempo)*ratio);
 #ifdef KMidDEBUG
-        printf("pausedat : %ld\n",pausedatmillisec);
+        printf("pausedat: %ld\n",pausedatmillisec);
 #endif
     }
     player->setTempoRatio(ratio);
