@@ -167,9 +167,7 @@ kmidFrame::kmidFrame(const char *name)
 		SLOT(options_FontChange()), actionCollection(),
 		"change_font");
 
-    (void)new KAction(i18n("Configure &Keys..."), 0, this,
-		SLOT(options_KeyConfig()), actionCollection(),
-		"configure_keys");
+    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
 
     (void)new KAction(i18n("MIDI &Setup..."), 0, this,
 		SLOT(options_MidiSetup()), actionCollection(), "midi_setup");
@@ -611,21 +609,12 @@ void kmidFrame::options_ChannelViewOptions()
   delete dlg;
 }
 
-void kmidFrame::options_KeyConfig()
+void kmidFrame::slotConfigureKeys()
 {
-  /*    if ( KKeyDialog::configureKeys( kKeysAccel ) )
-	{
-	kKeysAccel->changeMenuAccel(m_song,0,"Play/Pause");
-	kKeysAccel->changeMenuAccel(m_song,2,"Stop");
-	kKeysAccel->changeMenuAccel(m_song,4,"Previous Song");
-	kKeysAccel->changeMenuAccel(m_song,5,"Next Song");
-	kKeysAccel->changeMenuAccel(m_options,3,"See Text events");
-	kKeysAccel->changeMenuAccel(m_options,4,"See Lyrics events");
-
-	}
-   */
+    KKeyDialog::configure( actionCollection(), this );
 }
 
+
 void kmidFrame::openURL( const QString url )
 {
   int c=autoAddSongToCollection(url.ascii(),1);
