@@ -94,7 +94,8 @@ public slots:
     void options_ShowChannelView();
     void options_ChannelViewOptions();
     void options_FontChange();
-    void options_KeyConfig();
+    void slotConfigureKeys();
+
     void options_MidiSetup();
     void spacePressed();
 
