@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
@@ -34,7 +34,7 @@ RhythmView::~RhythmView()
     if (lamps!=NULL)
     {
         for (int i=0;i<num;i++) delete lamps[i];
-        delete lamps;
+        delete [] lamps;
         lamps=NULL;
     }
 }
@@ -45,7 +45,7 @@ void RhythmView::setRhythm(int numerator,int denominator)
     if (lamps!=NULL)
     {
         for (i=0;i<num;i++) delete lamps[i];
-        delete lamps;
+        delete [] lamps;
         lamps=NULL;
     }
     num=numerator;
