@@ -3,7 +3,7 @@
  *
  *    kmidi
  *
- * $Id: configdlg.cpp,v 1.24 2002/01/06 04:17:10 mueller Exp $
+ * $Id: configdlg.cpp,v 1.28 2002/07/07 20:42:14 binner Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -41,7 +41,7 @@
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 #include <kglobal.h>
-//#include <kcolorbtn.h>
+//#include <kcolorbutton.h>
 
 #include "configdlg.h"
 #include "kmidi.h"
@@ -81,9 +81,9 @@ ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *nam
 
     tl = new QVBoxLayout(this, 5);
     bbox = new KButtonBox(this);
-    ok = bbox->addButton(i18n("OK"));
+    ok = bbox->addButton(i18n("&OK"));
     ok->setDefault(TRUE);
-    cancel = bbox->addButton(i18n("Cancel"));
+    cancel = bbox->addButton(i18n("&Cancel"));
     cancel->setDefault(TRUE);
 
     connect(ok, SIGNAL(clicked()), this, SLOT(accept()));
@@ -104,10 +104,10 @@ ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *nam
     //box->setGeometry(10,10,320,260);
     configsize = QSize( 320+20, 260+80 );
 
-    QString str = i18n("The led color is used in<br>\nthe panel and meter.");
+    QString str = i18n("The LED color is used in<br>\nthe panel and meter.");
     label1 = new QLabel(w);
     label1->setGeometry(60,25,135,25);
-    label1->setText(i18n("LED Color:"));
+    label1->setText(i18n("LED color:"));
     what->add(label1, str);
 
     button1 = new KColorButton(configdata.led_color, w);
@@ -118,7 +118,7 @@ ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *nam
     str = i18n("This color is for<br>\nthe panel and meter backgrounds.");
     label2 = new QLabel(w);
     label2->setGeometry(60,85,135,25);
-    label2->setText(i18n("Background Color:"));
+    label2->setText(i18n("Background color:"));
     what->add(label2, str);
 
     button2 = new KColorButton(configdata.background_color, w);
@@ -126,19 +126,19 @@ ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *nam
     connect(button2,SIGNAL(changed( const QColor & )),this,SLOT(set_background_color( const QColor & )));
     what->add(button2, str);
 
-    ttcheckbox = new QCheckBox(i18n("Show Tool Tips"), w, "tooltipscheckbox");
+    ttcheckbox = new QCheckBox(i18n("Show tool tips"), w, "tooltipscheckbox");
     ttcheckbox->setGeometry(30,150,135,25);
     ttcheckbox->setFixedSize( ttcheckbox->sizeHint() );
     ttcheckbox->setChecked(configdata.tooltips);
     connect(ttcheckbox,SIGNAL(clicked()),this,SLOT(ttclicked()));
     what->add(ttcheckbox, i18n("Provide brief descriptions<br>\n"
-			       "when cursor is left over a<br>\n"
+			       "when cursor is left over an<br>\n"
 			       "object on the screen"));
 
     str = i18n("Try to stop KMidi from<br>\nusing up too much of your RAM.");
     label3 = new QLabel(w);
     label3->setGeometry(60,200,135,25);
-    label3->setText("Patch Mem Max:");
+    label3->setText("Patch mem max:");
     what->add(label3, str);
     meg = new KIntNumInput(configdata.max_patch_megs, w, 10, "hex_with_slider" );
     meg->setRange(0, 255);
@@ -218,7 +218,7 @@ ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *nam
 		i18n("A very good large soundfont (38 megs)."));
     patches->addContributor("Msdos sfark decompressor.", QString::null,
 		"http://www.melodymachine.com/",
-		i18n("You may need this msdos-only tool."));
+		i18n("You may need this MSDOS-only tool."));
 
     connect(patches, SIGNAL( sendEmail(const QString& , const QString& ) ),
 	this, SLOT ( sendEmailSlot(const QString& , const QString& ) ) );
