@@ -1,7 +1,7 @@
 /*
    kmidi 
    
-   $Id: ctl.cpp,v 1.18 2000/08/23 04:27:13 waba Exp $
+   $Id: ctl.cpp,v 1.20 2002/11/22 05:06:42 staikos Exp $
 
    Copyright 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -357,8 +357,8 @@ static void ctl_channel_note(int ch, /*int note, int vel,*/ int start)
 	Panel->chorusdepth[slot][ch] = (uint8)channel[ch].chorusdepth;
 	Panel->volume[slot][ch] = (uint8)channel[ch].volume;
 
-	//Panel->c_bank[ch] = (uint8)channel[ch].bank;
-	//Panel->c_variationbank[ch] = (uint8)channel[ch].variationbank;
+	/*Panel->c_bank[ch] = (uint8)channel[ch].bank; */
+	/*Panel->c_variationbank[ch] = (uint8)channel[ch].variationbank; */
 }
 
 static void ctl_note(int v)
@@ -1209,7 +1209,7 @@ static void shm_free(int sig)
 {
 	int status;
 #ifdef NOW_USING_SEMAPHORES
-#if defined(__linux__) || defined(__FreeBSD__)
+#if defined(__linux__) || defined(__FreeBSD__) || defined(__bsdi__)
 	union semun dmy;
 #else /* Solaris 2.x, BSDI, OSF/1, HPUX */
 	void *dmy;
