@@ -2,7 +2,7 @@
 
    kmidi - a midi to wav converter
 
-   $Id: kmidi.cpp,v 1.117.2.1 2002/12/12 12:10:36 waba Exp $
+   $Id: kmidi.cpp,v 1.117.2.2 2003/06/24 13:20:57 mueller Exp $
 
    Copyright 1997, 1998 Bernd Johannes Wuebben math.cornell.edu
 
@@ -1212,7 +1212,7 @@ void KMidi::redoplaybox()
 	if(filenamestr.right(4) == QString(".mid") ||filenamestr.right(4) == QString(".MID"))
 	    filenamestr = filenamestr.left(filenamestr.length()-4);
 	}
-	if (errindex == 0) filenamestr.insert('#',0);
+	if (errindex == 0) filenamestr.insert(0, '#');
 	playbox->insertItem(filenamestr);
     }
 }
