@@ -2,7 +2,7 @@
 
    kmidi - a midi to wav converter
 
-   $Id: kmidiframe.cpp,v 1.15.2.1 2002/04/14 12:56:21 lukas Exp $
+   $Id: kmidiframe.cpp,v 1.19 2002/08/14 21:16:08 binner Exp $
 
    Copyright 1997, 1998 Bernd Johannes Wuebben math.cornell.edu
 
@@ -107,14 +107,14 @@ KMidiFrame::KMidiFrame( const char *name ) :
 	view_level->setWhatsThis(101, i18n("The info window shows<br>\n"
 				"all displayable midi<br>\n"
 				"messages.") );
-        view_level->insertItem( i18n("Loading msgs") , 102);
+        view_level->insertItem( i18n("Loading Msgs") , 102);
 	view_level->setWhatsThis(102, i18n("Also shows new instruments<br>\n"
 				"being loaded for playing<br>\n"
 				"the next song.") );
-        view_level->insertItem( i18n("debug 1") , 103);
+        view_level->insertItem( i18n("Debug 1") , 103);
 	view_level->setWhatsThis(103, i18n("Also shows instrument<br>\n"
 				"volume computation.") );
-        view_level->insertItem( i18n("debug 2") , 104);
+        view_level->insertItem( i18n("Debug 2") , 104);
 	view_level->setWhatsThis(104, i18n("Shows lots of additional<br>\n"
 				"information (probably not useful).") );
     connect( view_level, SIGNAL(activated(int)), this, SLOT(doViewInfoLevel(int)) );
@@ -126,7 +126,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
     editMenu->insertItem( i18n("Edit Playlist"), kmidi, SLOT(ejectClicked()), 0, 108);
 	editMenu->setWhatsThis(108, i18n("Transfer the current<br>\n"
 				"play list to the Playlist Editor<br>\n"
-				"and start him up.") );
+				"and start it up.") );
 
 
 
@@ -154,7 +154,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
 				"velocity.") );
 	stereo_options->insertSeparator();
 	stereo_options->insertItem(  i18n("Surround Stereo") , 113);
-	stereo_options->setWhatsThis(112, i18n("Extra stereo, echo, and<br>" \
+	stereo_options->setWhatsThis(112, i18n("Extra stereo, echo and<br>" \
 				"detuned notes are spread out more<br>" \
 				"to left and right.") );
 
@@ -194,14 +194,14 @@ KMidiFrame::KMidiFrame( const char *name ) :
 				"is set to a minimum level of 96." ) );
         reverb_level->insertItem( i18n("midi level 127") , 164);
 	reverb_level->setWhatsThis(164, i18n("The reverberation level<br>\n"
-				"is set to the maximem level of 127." ) );
+				"is set to the maximum level of 127." ) );
     connect( reverb_level, SIGNAL(activated(int)), this, SLOT(doReverbLevel(int)) );
     connect( reverb_level, SIGNAL(aboutToShow()), this, SLOT(fixReverbLevelItems()) );
     reverb_options->insertSeparator();
-	reverb_options->insertItem(  i18n("No echo"), 120 );
+	reverb_options->insertItem(  i18n("No Echo"), 120 );
 	reverb_options->setWhatsThis(120, i18n("Prevents playing extra<br>\n"
 				"echo notes for reverberation.") );
-	reverb_options->insertItem(  i18n("Normal echo") , 121);
+	reverb_options->insertItem(  i18n("Normal Echo") , 121);
 	reverb_options->setWhatsThis(121, i18n("Extra echo notes are<br>\n"
 					       "played to get the effect<br>\n"
 					       "of reverberation.") );
@@ -209,7 +209,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
     Q_CHECK_PTR( echo_level );
     echo_level->setCheckable( TRUE );
     reverb_options->insertSeparator();
-    reverb_options->insertItem( i18n("Echo level"), echo_level);
+    reverb_options->insertItem( i18n("Echo Level"), echo_level);
         echo_level->insertItem( i18n("default") , 130);
 	echo_level->setWhatsThis(130, i18n("The level for echo notes<br>\n"
 				"is set according to the midi<br>\n"
@@ -226,7 +226,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
 				"is set to a minimum level of 96." ) );
         echo_level->insertItem( i18n("midi level 127") , 134);
 	echo_level->setWhatsThis(133, i18n("The echo level<br>\n"
-				"is set to the maximem level of 127." ) );
+				"is set to the maximum level of 127." ) );
     connect( echo_level, SIGNAL(activated(int)), this, SLOT(doEchoLevel(int)) );
     connect( echo_level, SIGNAL(aboutToShow()), this, SLOT(fixEchoLevelItems()) );
 
@@ -240,23 +240,23 @@ KMidiFrame::KMidiFrame( const char *name ) :
     chorus_level = new QPopupMenu();
     Q_CHECK_PTR( chorus_level );
     chorus_level->setCheckable( TRUE );
-    chorus_options->insertItem( i18n("Chorus level"), chorus_level);
+    chorus_options->insertItem( i18n("Chorus Level"), chorus_level);
     chorus_level->insertItem( i18n("default") , 170);
     chorus_level->setWhatsThis(170, i18n("The chorus level<br>\n"
 					 "is set according to the midi<br>\n"
 					 "channel setting and what the<br>\n"
 					 "instrument patch specifies.") );
     chorus_level->insertItem( i18n("midi level  32") , 171);
-    chorus_level->setWhatsThis(171, i18n("The choruslevel<br>\n"
+    chorus_level->setWhatsThis(171, i18n("The chorus level<br>\n"
 					 "is set to a minimum level of 32." ) );
     chorus_level->insertItem( i18n("midi level  64") , 172);
-    chorus_level->setWhatsThis(172, i18n("The choruslevel<br>\n"
+    chorus_level->setWhatsThis(172, i18n("The chorus level<br>\n"
 					 "is set to a minimum level of 64." ) );
     chorus_level->insertItem( i18n("midi level  96") , 173);
-    chorus_level->setWhatsThis(173, i18n("The choruslevel<br>\n"
+    chorus_level->setWhatsThis(173, i18n("The chorus level<br>\n"
 					 "is set to a minimum level of 96." ) );
     chorus_level->insertItem( i18n("midi level 127") , 174);
-    chorus_level->setWhatsThis(174, i18n("The choruslevel<br>\n"
+    chorus_level->setWhatsThis(174, i18n("The chorus level<br>\n"
 					 "is set to the maximum level of 127." ) );
     connect( chorus_level, SIGNAL(activated(int)), this, SLOT(doChorusLevel(int)) );
     connect( chorus_level, SIGNAL(aboutToShow()), this, SLOT(fixChorusLevelItems()) );
@@ -275,9 +275,9 @@ KMidiFrame::KMidiFrame( const char *name ) :
     chorus_options->insertItem( i18n("Detune Level"), detune_level);
     detune_level->insertItem( i18n("default") , 150);
     detune_level->setWhatsThis(150, i18n("The level for detuned notes<br>\n"
-					 "is set according to the midi<br>\n"
+					 "is set according to the MIDI<br>\n"
 					 "channel setting and what the<br>\n"
-					 "instrument patch specifies for"
+					 "instrument patch specifies for "
 					 "chorus level.") );
     detune_level->insertItem( i18n("midi level  32") , 151);
     detune_level->setWhatsThis(151, i18n("The detuning level<br>\n"
