@@ -1,7 +1,7 @@
 /*
  *        kmidi - midi to wav player/converter
  *
- * $Id: log.h,v 1.9 2001/05/13 01:55:26 gebauer Exp $
+ * $Id: log.h,v 1.9.6.1 2003/02/25 16:13:35 rnolden Exp $
  *            Copyright (C) 1997  Bernd Wuebben
  *                 wuebben@math.cornel.edu 
  * 
@@ -27,7 +27,7 @@
 
 #include<qstring.h>
 //#include<qpixmap.h>
-#include<qmultilinedit.h>
+#include<qmultilineedit.h>
 #include <qtimer.h>
 #include <qstrlist.h>
 
