@@ -3,6 +3,7 @@
  *
  *
  * Copyright (C) 2000 Stefan Schimanski <1Stein@gmx.de>
+ * Copyright (C) 2003 Sven Leiber <s.leiber@web.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KMIXDOCKWIDGET_H
@@ -38,6 +39,7 @@ class KMixDockWidget : public KSystemTray  {
    ~KMixDockWidget();
 
    void updatePixmap();
+   void setErrorPixmap();
 
  public slots:  
    void setVolumeTip(int, Volume);
