@@ -3,7 +3,7 @@
 
 Volume::Volume( int channels, int maxVolume )
 {
-  v_volumes = QArray<int>( channels );
+  v_volumes = QMemArray<int>( channels );
   v_maxVolume = maxVolume;
   v_muted = false;
 }
