@@ -5,8 +5,9 @@
  *
  *      --- This file has been manually midified ---
  *
+ * WABA: Can you use kmidi to play it?
  *
- * $Id: CDDBSetupData.cpp,v 1.27 2002/02/03 10:06:28 mlaurent Exp $
+ * $Id: CDDBSetupData.cpp,v 1.30 2002/07/07 21:02:28 binner Exp $
  *
  ***********************************************************************/
 
@@ -44,7 +45,7 @@ CDDBSetupData::CDDBSetupData
 	QBoxLayout * lay2 = new QVBoxLayout ( group, 10, 0 );
 
 	QBoxLayout * lay3 = new QHBoxLayout ( lay2, 5 );
-	remote_cddb_cb = new QCheckBox( i18n("Enable Remote freedb"), group, "CheckBox_1" );
+	remote_cddb_cb = new QCheckBox( i18n("Enable remote freedb"), group, "CheckBox_1" );
 	connect( remote_cddb_cb, SIGNAL(toggled(bool)), SLOT(enable_remote_cddb(bool)) );
 	lay3->addWidget ( remote_cddb_cb );
 	lay3->addSpacing ( 15 );
@@ -83,10 +84,10 @@ CDDBSetupData::CDDBSetupData
 	/* edm new section end */
 
 	lay2->addSpacing ( fm.lineSpacing() );
-	QLabel* dlgedit_Label_8 = new QLabel( i18n("freedb Base Directory:"), group, "Label_8" );
+	QLabel* dlgedit_Label_8 = new QLabel( i18n("freedb base directory:"), group, "Label_8" );
 	lay2->addWidget ( dlgedit_Label_8 );
         basedir_edit = new KURLRequester(group, "LineEdit_4" );
-        basedir_edit->fileDialog()->setMode(KFile::Directory);
+        basedir_edit->setMode(KFile::Directory);
 
 	lay2->addWidget ( basedir_edit );
 
