@@ -2,7 +2,7 @@
  *
  * kscd -- A simple CD player for the KDE project           
  *
- * $Id: cddb.h,v 1.25 2002/02/22 20:42:42 leitner Exp $
+ * $Id: cddb.h,v 1.27.2.1 2002/12/07 05:07:59 staikos Exp $
  * 
  * Copyright (C) 1997 Bernd Johannes Wuebben 
  * wuebben@math.cornell.edu
@@ -32,11 +32,11 @@
 #include <qstring.h>
 #include <qstrlist.h>
 
-#include <ksock.h>
+#include <qsocket.h>
 
 #define DEFAULT_SUBMIT_EMAIL "freedb-submit@freedb.org"
 #define DEFAULT_TEST_EMAIL ""
-#define DEFAULT_CDDB_SERVER "freedb.freedb.org cddbp 888 -"
+#define DEFAULT_CDDB_SERVER "freedb.freedb.org cddbp 8880 -"
 #define DEFAULT_CDDBHTTP_SERVER "freedb.freedb.org http 80 /~cddb/cddb.cgi"
 
 #define CDDB_READ_BUFFER_LEN  2024
@@ -119,7 +119,7 @@ class CDDB:public QObject
     bool    useHTTPProxy();
     QString getHTTPProxyHost();
     unsigned short int getHTTPProxyPort();
-   
+
  protected:
     
     void 	do_state_machine();
@@ -133,10 +133,14 @@ class CDDB:public QObject
 
     void	 cddb_connect(QString& server);
     void	 cddb_connect_internal();
-    void         cddb_read(KSocket* sock);
-    void         cddb_close(KSocket* sock);
+    void         cddb_read();
+    void         cddb_close();
     void         cddb_timed_out_slot();
 
+    void slotErrorConnection(int);
+    void slotConnected();
+    void slotConnectionClosed();
+
  signals:
 
     void        cddb_done();
@@ -150,9 +154,6 @@ class CDDB:public QObject
 
  private:
 
-    QString     domainname;
-    QString     username;
-
     QStringList    inexact_list;
     QTimer 	starttimer;
     QTimer 	timeouttimer;
@@ -173,7 +174,7 @@ class CDDB:public QObject
     unsigned short int port;
     bool    	connected;
     bool	readonly;
-    KSocket	*sock;
+    QSocket	*sock;
 
     CDDBState	state;
     CDDBMode    mode;
@@ -186,6 +187,8 @@ class CDDB:public QObject
     unsigned long magicID;
     int         protocol_level;
 
+    QString RequestFrom;
+
 };
 
 #endif
