@@ -2,7 +2,7 @@
  *
  * ConfigDlg - the configuration dialog for kscd
  *
- * $Id: configdlg.h,v 1.18 2002/01/11 03:27:02 aseigo Exp $
+ * $Id: configdlg.h,v 1.20 2002/09/19 20:05:00 aseigo Exp $
  *
  * Copyright (C) 2002 Aaron J. Seigo <aseigo@olympusproject.org>
  * 
@@ -51,6 +51,8 @@ class ConfigDlg : public KDialogBase
          */
         CDDBSetup* cddb() { return mCDDBConfig; }
 
+        void updateGlobalSettings();
+
     protected slots: 
         void slotApply();
         void slotOk();
@@ -61,7 +63,7 @@ class ConfigDlg : public KDialogBase
         CDDBSetup* mCDDBConfig;
         SMTPConfig* mSMTPConfig;
         KSCD* mPlayer;
-#if KSCDMAGIC
+#ifdef KSCDMAGIC
         MGConfigDlg* mMagicConfig;
 #endif
 
