@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: kscd.cpp,v 1.176.2.5 2003/07/04 15:14:14 wstephens Exp $
+ * $Id: kscd.cpp,v 1.176.2.7 2003/09/08 22:57:23 mueller Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -80,7 +80,9 @@ extern "C" {
 #include "bitmaps/rew.xbm"
 #include "bitmaps/info.xbm"
 #include "bitmaps/poweroff.xbm"
+#ifdef KSCDMAGIC
 #include "bitmaps/magic.xbm"
+#endif
 #include "bitmaps/eject.xbm"
 #include "bitmaps/db.xbm"
 #include "bitmaps/logo.xbm"
@@ -170,7 +172,7 @@ class KSCDSlider : public QSlider
 *****************************************************************************/
 
 KSCD::KSCD( QWidget *parent, const char *name )
-  :   QWidget( parent, name, Qt::WDestructiveClose ), DCOPObject("CDPlayer")
+  :   DCOPObject( "CDPlayer" ), QWidget( parent, name, Qt::WDestructiveClose )
 {
   magicproc           = 0L;
   cd_device_str       = "";
@@ -3122,6 +3124,7 @@ void KSCD::clearSongList()
     songListCB->clear();
     if (tooltips)
     {
+        QToolTip::remove(songListCB);
         QToolTip::add(songListCB, i18n("Track list"));
     }
 }
@@ -3154,6 +3157,7 @@ void KSCD::setSongListTo(int whichTrack)
         QString justTheName = songListCB->currentText();
         justTheName = justTheName.right(justTheName.length() - 4);
 
+        QToolTip::remove(songListCB);
         QToolTip::add(songListCB, i18n("Current Track: %1").arg(justTheName));
     }
 }
