@@ -1,7 +1,7 @@
 /*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: kscd.h,v 1.64 2002/10/13 07:07:11 aseigo Exp $
+   $Id: kscd.h,v 1.64.2.1 2003/07/04 15:14:14 wstephens Exp $
 
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -113,6 +113,10 @@ class KSCD : public QWidget, public KSessionManaged, virtual public DCOPObject {
 
 
 k_dcop:
+    /**
+     * Check KsCD's current state
+     */
+    bool playing();
     void play() { playClicked(); }
     void stop() { stopClicked(); }
     void previous() { prevClicked(); }
