@@ -1,5 +1,5 @@
 /*
- * $Id: cdinfo.c,v 1.2 2000/05/30 15:18:44 dfoerste Exp $
+ * $Id: cdinfo.c,v 1.2.10.1 2002/12/09 14:34:54 lunakl Exp $
  * 
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Get information about a CD.
  */
 
-static char cdinfo_id[] = "$Id: cdinfo.c,v 1.2 2000/05/30 15:18:44 dfoerste Exp $";
+static char cdinfo_id[] = "$Id: cdinfo.c,v 1.2.10.1 2002/12/09 14:34:54 lunakl Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -544,11 +544,13 @@ stash_cdinfo(char *artist, char *cdname, int autoplay, int playmode )
 	{
 		if (strcmp(cd->artist, artist))
 			info_modified = 1;
-		strcpy(cd->artist, artist);
+		strncpy(cd->artist, artist,sizeof(cd->artist)-1);
+                cd->artist[sizeof(cd->artist)-1]='\0';
 
 		if (strcmp(cd->cdname, cdname))
 			info_modified = 1;
-		strcpy(cd->cdname, cdname);
+		strncpy(cd->cdname, cdname,sizeof(cd->cdname)-1);
+                cd->cdname[sizeof(cd->cdname)-1]='\0';
 
 		if (!!cd->autoplay != !!autoplay)
 			info_modified = 1;
