@@ -1,5 +1,5 @@
 /*
- * $Id: cdrom.c,v 1.13 2002/02/26 17:49:13 neil Exp $
+ * $Id: cdrom.c,v 1.15 2002/10/27 17:54:08 aseigo Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * platform- or drive-dependent code here.
  */
 
-static char cdrom_id[] = "$Id: cdrom.c,v 1.13 2002/02/26 17:49:13 neil Exp $";
+static char cdrom_id[] = "$Id: cdrom.c,v 1.15 2002/10/27 17:54:08 aseigo Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -328,14 +328,14 @@ wm_cd_status( void )
 	if(drive.get_drive_status == NULL)
 	{
 		perror("CD get drive status: function pointer NULL");
-		return (-1);
+		return (WM_CDM_UNKNOWN);
 	}
 
 	if( (drive.get_drive_status)(&drive, oldmode, &mode, &cur_frame,
 					&trackno, &cur_index) < 0)
 	{
 		perror("CD get drive status");
-		return (-1);
+		return (WM_CDM_UNKNOWN);
 	}
 	oldmode = mode;
 
@@ -366,7 +366,7 @@ wm_cd_status( void )
                 {
 		    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS_MISC,"status: returned toc was NULL\n");
 		    cur_cdmode = WM_CDM_NO_DISC;
-		    return (-1);
+		    return (WM_CDM_UNKNOWN);
 		}
 
 		cur_nsections = 0;
@@ -407,7 +407,7 @@ wm_cd_status( void )
 		/* Fall through */
 
 	case WM_CDM_STOPPED:
-		if (cur_track >= 1 && cur_track <= cur_ntracks)
+		if (cur_track >= 1 && cur_track <= cur_ntracks && cd->trk != NULL)
 		{
 			cur_trackname = cd->trk[cur_track-1].songname;
 			cur_avoid = cd->trk[cur_track-1].avoid;
@@ -427,7 +427,12 @@ wm_cd_status( void )
 		if (cur_pos_abs < 0)
 			cur_pos_abs = cur_frame = 0;
 
-		if (cur_track < 1)
+		if (cd == NULL)
+        {
+            ret = WM_CDM_UNKNOWN;
+			cur_tracklen = 0;
+        }
+		else if (cur_track < 1)
 			cur_tracklen = cd->length;
 		else
 			cur_tracklen = cd->trk[cur_track-1].length;
