@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.17 2002/11/16 23:12:48 waba Exp $
+ * $Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37 staikos Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17 2002/11/16 23:12:48 waba Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37 staikos Exp $";
 
 #if defined(__linux__)
 
@@ -275,7 +275,7 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
   cdc.buflen = retbuflen;
   cdc.stat = 0;
   cdc.sense = &sense;
-  cdc.data_direction = getreply;
+  cdc.data_direction = getreply?CGC_DATA_READ:CGC_DATA_WRITE;
 
   /* sendpacket_over_cdrom_interface() */
   return ioctl(d->fd, CDROM_SEND_PACKET, &cdc);
