@@ -24,7 +24,7 @@
  */
 
 
-static char plat_osf_id[] = "$Id: plat_osf1.c,v 1.8 2001/01/30 05:56:20 dfoerste Exp $";
+static char plat_osf_id[] = "$Id: plat_osf1.c,v 1.9 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(__osf__) || defined(__osf)
 
@@ -46,6 +46,8 @@ static char plat_osf_id[] = "$Id: plat_osf1.c,v 1.8 2001/01/30 05:56:20 dfoerste
 #include "include/wm_config.h"
 #include "include/wm_struct.h"
 #include "include/wm_helpers.h"
+#include "include/wm_cdtext.h"
+
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -655,4 +657,15 @@ gen_get_volume( struct wm_drive *d, int *left, int *right )
   return (0);
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return -1; /* no SCSI, no CDTEXT */
+} /* gen_get_cdtext() */
+
+
 #endif
