@@ -1,5 +1,5 @@
 /*
- * $Id: plat_sun.c,v 1.10 2001/01/30 05:56:20 dfoerste Exp $
+ * $Id: plat_sun.c,v 1.11 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Sun-specific drive control routines.
  */
 
-static char plat_sun_id[] = "$Id: plat_sun.c,v 1.10 2001/01/30 05:56:20 dfoerste Exp $";
+static char plat_sun_id[] = "$Id: plat_sun.c,v 1.11 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(sun) || defined(__sun)
 
@@ -42,7 +42,7 @@ static char plat_sun_id[] = "$Id: plat_sun.c,v 1.10 2001/01/30 05:56:20 dfoerste
 #include "include/wm_config.h"
 #include "include/wm_helpers.h"
 #include "include/wm_cdrom.h"
-
+#include "include/wm_cdtext.h"
 
 #include <ustat.h>
 #include <unistd.h>
@@ -1210,4 +1210,15 @@ codec_stop( void ) { return 0; }
 
 #endif /* CODEC } */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  /* This needs to be tested */
+  return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
+} /* gen_get_cdtext() */
+
 #endif /* sun } */
