@@ -1,5 +1,5 @@
 /*
- * $Id: plat_ultrix.c,v 1.8 2001/01/30 05:56:20 dfoerste Exp $
+ * $Id: plat_ultrix.c,v 1.9 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * ULTRIX 4.2 drive control routines.
  */
 
-static char plat_ultrix_id[] = "$Id: plat_ultrix.c,v 1.8 2001/01/30 05:56:20 dfoerste Exp $";
+static char plat_ultrix_id[] = "$Id: plat_ultrix.c,v 1.9 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(ultrix) || defined(__ultrix)
 
@@ -43,6 +43,7 @@ static char plat_ultrix_id[] = "$Id: plat_ultrix.c,v 1.8 2001/01/30 05:56:20 dfo
 #include <sys/cdrom.h>
 
 #include "include/wm_config.h"
+#include "include/wm_cdtext.h"
 #include "include/wm_struct.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
@@ -645,5 +646,15 @@ gen_get_volume(struct wm_drive *d, int *left, int *right)
   return (0);
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return -1; /* No SCSI, no CDTEXT */
+} /* gen_get_cdtext() */
+
 
 #endif
