@@ -18,7 +18,8 @@
 #include "../yafcore/yaf_control.h"
 #include "../yafxplayer/inputDecoderYAF.h"
 
-#include <iostream.h>
+#include <iostream>
+using namespace std;
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
