@@ -13,6 +13,10 @@
 
 #include "vorbisPlugin.h"
 
+#include <iostream>
+
+using namespace std;
+
 #ifdef OGG_VORBIS
 
 size_t fread_func(void *ptr, size_t size, size_t nmemb, void *stream) {
@@ -249,6 +253,7 @@ void VorbisPlugin::decoder_loop() {
     case _STREAM_STATE_WAIT_FOR_END:
       // exit while loop
       lDecoderLoop=false;
+      usleep(2000000);
       break;
     default:
       cout << "unknown stream state vorbis decoder:"<<streamState<<endl;
