@@ -10,10 +10,12 @@
 
  */
 
+typedef unsigned long long __u64;
 
 #include "cdromToc.h"
 #include "cdromRawAccess.h"
 #include <sys/types.h>
+#define _LINUX_BYTEORDER_SWAB_H
 #include <linux/cdrom.h>
 #include <sys/ioctl.h>
 
