@@ -14,7 +14,9 @@
 
 #include "cdromRawAccess.h"
 
+#include <iostream>
 
+using namespace std;
 
 CDRomRawAccess::CDRomRawAccess(CDRomToc* cdromToc) {
   cdfile=NULL;
