@@ -18,7 +18,9 @@
 #define INADDR_NONE 0xffffffff
 #endif
 
+#include <iostream>
 
+using namespace std;
 
 static const char *httpstr="http://";
 
