@@ -20,13 +20,14 @@
 #include "fileInputStream.h"
 #include "cdromInputStream.h"
 #include "bufferInputStream.h"
-
+#include "threadSafeInputStream.h"
+#include "cddaInputStream.h"
 #include <string.h>
 
 #include "inputDetector.h"
 
 
-
+#define _INPUT_THREADSAFE     1
 
 class InputPlugin {
 
@@ -35,7 +36,9 @@ class InputPlugin {
   ~InputPlugin();
 
   static InputStream* createInputStream(int inputType);
+  static InputStream* createInputStream(int inputType,int lThreadSafe);
   static InputStream* createInputStream(const char* dest);
+  static InputStream* createInputStream(const char* dest,int lThreadSafe);
   static int getInputType(const char* dest);
 
 };
