@@ -17,7 +17,6 @@
 
 
 #include <stdio.h>
-#include <iostream.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -128,6 +127,7 @@ class ImageBase {
 
   virtual void ditherImage(YUVPicture* pic);
   virtual void putImage();
+  virtual void putImage(int w,int h);
 
   virtual int active() { return true; }
 
