@@ -62,9 +62,8 @@
 
 extern const char *ERR_XI_STR[];
 
-class XWindow {
+struct XWindow {
 
- public:
   Display *display;
   Window window;
   Screen *screenptr;
