@@ -13,10 +13,8 @@
 #include "nullPlayObject_impl.h"
 #include "debug.h"
 
-using namespace Arts;
-
 NULLPlayObject_impl::NULLPlayObject_impl() {
-  _state=posIdle;
+  _state=Arts::posIdle;
 
 }
 
@@ -45,7 +43,7 @@ void NULLPlayObject_impl::description(const string &) {
   // what should do this?
 }
 
-poTime NULLPlayObject_impl::currentTime() {
+Arts::poTime NULLPlayObject_impl::currentTime() {
   poTime time;
   return time;
 }
@@ -59,7 +57,7 @@ poTime NULLPlayObject_impl::overallTime() {
 
 poCapabilities NULLPlayObject_impl::capabilities() {
   arts_debug("capabilities");
-  return capPause;  /* no seek supported */
+  return Arts::capPause;  /* no seek supported */
 }
 
 string NULLPlayObject_impl::mediaName() {
@@ -75,7 +73,7 @@ poState NULLPlayObject_impl::state() {
 
 void NULLPlayObject_impl::play() {
   arts_debug("NULLPlayObject_impl::play");
-  _state = posPlaying;
+  _state = Arts::posPlaying;
 }
 
 void NULLPlayObject_impl::seek(const class poTime& seekTime) {
@@ -87,12 +85,12 @@ void NULLPlayObject_impl::seek(const class poTime& seekTime) {
 
 void NULLPlayObject_impl::pause() {
   arts_debug("NULLPlayObject_impl::pause");
-  _state = posPaused;
+  _state = Arts::posPaused;
 }
 
 void NULLPlayObject_impl::halt() {
   arts_debug("NULLPlayObject_impl::halt");
-  _state=posIdle;
+  _state=Arts::posIdle;
 }
  
 
