@@ -88,19 +88,19 @@ public:
 		__asm__ __volatile__(
 			"pushl $100                       \n"
 			"fildl (%%esp)                    \n"
-#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ == 2)
+#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 2)
 			"addl $4, %%esp                   \n"
 #endif
 			"fildl %5                         \n"
 			"fdivp                            \n" // percent / 100.0
-#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ == 2)
+#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 2)
 			"pushl $100                       \n"
 #endif
 			"fstps (%%esp)                    \n"
 			"movss (%%esp), %%xmm1            \n"
 			"shufps $0x00, %%xmm1, %%xmm1     \n" // percentage in all of xmm1
 			"addl $4, %%esp                   \n"
-#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ == 2)
+#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 2)
 			"subl $4, %4                      \n"
 			"jl .l2                           \n" // samples < 4
 #else
@@ -124,7 +124,7 @@ public:
 		
 			"incl %%ecx                       \n"
 			"incl %%ecx                       \n"
-#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ == 2)
+#if defined(__GNUC__) && (__GNUC__ == 3 && __GNUC_MINOR__ >= 2)
 			"subl $4, %4                      \n"
 			"jge .l1                          \n"
 			".l2:                             \n"
