@@ -217,9 +217,11 @@ void LibraryLoader::setModules(const QStringList &mods)
 	KGlobal::config()->sync();
 }
 
-bool LibraryLoader::remove(const QString &spec)
+bool LibraryLoader::remove(const QString& spec, bool terminateOnLastUI)
 {
 	removeNow(spec);
+	if ( !terminateOnLastUI )
+		return true;
 
 	// exit if this is the last UI
 	if (getInfo(spec).type=="userinterface")
@@ -242,6 +244,12 @@ bool LibraryLoader::remove(const QString &spec)
 	}
 
 	return true;
+
+}
+
+bool LibraryLoader::remove(const QString &spec)
+{
+	remove(spec, true);
 }
 
 bool LibraryLoader::remove(const PluginLibrary *pl)
