@@ -50,6 +50,8 @@
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kwin.h>
+#include <kurldrag.h>
+
 #include <qbitmap.h>
 #include <qdragobject.h>
 #include <qlabel.h>
@@ -232,11 +234,11 @@ void Excellent::dragEnterEvent(QDragEnterEvent *event)
 
 void Excellent::dropEvent(QDropEvent *event)
 {
-	QStrList uri;
-	if (QUriDrag::decode(event, uri))
+	KURL::List uri;
+	if (KURLDrag::decode(event, uri))
 	{
-		for(char *file = uri.first(); file != 0; file = uri.next() )
-			napp->player()->openFile(KURL(file), false);
+		for (KURL::List::Iterator i = uri.begin(); i != uri.end(); ++i)
+			napp->player()->openFile(*i, false);
 	}
 }
 
@@ -264,13 +266,17 @@ void Excellent::slotPaused()
 void Excellent::slotTimeout()
 {
 	if(volumeSlider) volumeSlider->setValue(100 - napp->player()->volume());
-	handleLengthString(napp->player()->lengthString());
+
+	if (!slider->currentlyPressed())
+		handleLengthString(napp->player()->lengthString());
 
 	if(!napp->player()->current()) return;
 	if(slider->currentlyPressed()) return;
 
 	slider->setRange(0, (int)napp->player()->getLength() / 1000 );
 	slider->setValue((int)napp->player()->getTime() / 1000 );
+
+	changeStatusbar();
 }
 
 void Excellent::sliderMoved(int seconds)
@@ -292,22 +298,22 @@ void Excellent::changeLoopType(int t)
 	case Player::None:
 		statusBar()->message(i18n("No looping"), time);
 		loop->setIcon("noatunloopnone");
-		loop->setText(i18n("No looping"));
+		loop->setText(i18n("No Looping"));
 		break;
 	case Player::Song:
 		statusBar()->message(i18n("Song looping"), time);
 		loop->setIcon("noatunloopsong");
-		loop->setText(i18n("Song looping"));
+		loop->setText(i18n("Song Looping"));
 		break;
 	case Player::Playlist:
 		statusBar()->message(i18n("Playlist looping"), time);
 		loop->setIcon("noatunloopplaylist");
-		loop->setText(i18n("Playlist looping"));
+		loop->setText(i18n("Playlist Looping"));
 		break;
 	case Player::Random:
 		statusBar()->message(i18n("Random play"), time);
 		loop->setIcon("noatunlooprandom");
-		loop->setText(i18n("Random play"));
+		loop->setText(i18n("Random Play"));
 	}
 }
 
