@@ -16,10 +16,11 @@ class IRPrefs : public CModule
 {
 Q_OBJECT
 public:
-	enum Action 
+	enum Action
 	{
-		None, Play, Stop, Pause, Mute, 
-		Previous, Next, VolumeDown, VolumeUp
+		None, Play, Stop, Pause, Mute,
+		Previous, Next, VolumeDown, VolumeUp,
+		SeekBackward, SeekForward, ShowPlaylist
 	};
 	
 	IRPrefs(QObject *parent);
