@@ -30,7 +30,6 @@
 #include <klocale.h>
 #include <qtimer.h>
 
-#include <iostream.h>
 #include <stdlib.h>
 #include <unistd.h>
 
@@ -39,6 +38,9 @@
 #include <noatun/app.h>
 #include <noatun/stdaction.h>
 
+const bool KaimanStyleSlider::optionVertical = 1;
+const bool KaimanStyleSlider::optionReversed = 2;
+const bool KaimanStyleText::optionExtended = 1;
 
 KaimanStyleElement::KaimanStyleElement(QWidget *parent, const char *name)
     : QWidget(parent, name)
