@@ -7,8 +7,8 @@
 
 // local includes
 #include "kjloader.h"
+#include "kjloader.moc"
 #include "kjwidget.h"
-
 #include "kjbackground.h"
 #include "kjbutton.h"
 #include "kjfont.h"
@@ -36,7 +36,6 @@
 
 // system includes
 #include <string.h>
-#include <iostream.h>
 #include <math.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -67,7 +66,6 @@
 #include <kurldrag.h>
 
 #include <kwin.h>
-//#include <X11/Xlib.h>
 #include <kiconloader.h>
 
 class KJToolTip : public QToolTip
@@ -80,6 +78,9 @@ public:
 protected:
 	virtual void maybeTip(const QPoint &p)
 	{
+		if ( !mParent->prefs()->displayTooltips() )
+			return;
+
 		QPtrList<KJWidget> things=mParent->widgetsAt(p);
 		for (KJWidget *i=things.first(); i!=0; i=things.next())
 		{
@@ -97,35 +98,34 @@ private:
 };
 
 
-
 KJLoader *KJLoader::kjofol=0;
 
 
 KJLoader::KJLoader(void)
-	: QWidget(0,"KJLoader", WType_TopLevel | WStyle_NoBorderEx | WRepaintNoErase /*| WX11BypassWM */),
+	: QWidget(0,"KJLoader", WType_TopLevel | WStyle_NoBorderEx | WRepaintNoErase ),
 	  UserInterface(), moving(false), mClickedIn(0), mText(0), mNumbers(0), mVolumeFont(0), mPitchFont(0), splashScreen(0)
 {
-	kjofol=this;
+	kjofol = this;
 
 	mTooltips = new KJToolTip(this);
 
 	// Windowname and Icon
-	setCaption("Noatun");
-	setIcon(SmallIcon("noatun"));
-	setAcceptDrops(true);
+	setCaption ( i18n("Noatun") );
+	setIcon ( SmallIcon("noatun") );
+	setAcceptDrops ( true );
 
 	// We're going to draw over everything, there is no point in drawing the grey background first
 	setBackgroundMode(NoBackground);
 
 	// used for dockmode
 	mWin = new KWinModule();
-//	mNetRootInfo = new NETRootInfo (qt_xdisplay(), 0 );
 
 	subwidgets.setAutoDelete(true);
 
-	KConfig *config=KGlobal::config();
-	config->setGroup("KJofol-Skins");
-	QString skin = config->readEntry("SkinResource", locate("data", "noatun/kjskins/kjofol/kjofol.rc"));
+	mPrefs = new KJPrefs(this);
+	connect ( mPrefs, SIGNAL(configChanged()), this, SLOT(readConfig()) );
+
+	QString skin = mPrefs->skin();
 	if ( QFile(skin).exists() )
 	{
 		loadSkin(skin);
@@ -137,10 +137,6 @@ KJLoader::KJLoader(void)
 		napp->preferences();
 	}
 
-	/* KJPrefs *prefs = */new KJPrefs(this);
-//	connect ( prefs, SIGNAL(configChanged()), this, SLOT(readConfig()) );
-
-//	kdDebug(66666) << "connecting signals and slots..." << endl;
 	mHelpMenu = new KHelpMenu(this, kapp->aboutData());
 	connect( napp->player(), SIGNAL(timeout()), SLOT(timeUpdate()));
 	connect( napp->player(), SIGNAL(newSong()), SLOT(newSong()));
@@ -149,11 +145,10 @@ KJLoader::KJLoader(void)
 
 	connect( napp, SIGNAL(hideYourself()), SLOT(hide()) );
 	connect( napp, SIGNAL(showYourself()), SLOT(show()) );
-//	kdDebug(66666) << "connected to noatun signals" << endl;
 //	KStdAction::quit(napp, SLOT(quit()), actionCollection());
 
 	QApplication::restoreOverrideCursor();
-	newSong();
+//	newSong();
 }
 
 QPtrList<KJWidget> KJLoader::widgetsAt(const QPoint &pt) const
@@ -168,7 +163,8 @@ QPtrList<KJWidget> KJLoader::widgetsAt(const QPoint &pt) const
 
 void KJLoader::removeChild(KJWidget *c)
 {
-	if ( mClickedIn == c ) mClickedIn=0;
+	if ( mClickedIn == c )
+		mClickedIn = 0;
 	if (subwidgets.findRef(c) != -1)
 		subwidgets.take();
 }
@@ -202,8 +198,12 @@ void KJLoader::loadSkin(const QString &file)
 
 	KJPitchText *pitchText=0;
 	KJVolumeText *volumeText=0;
+	mText = 0;
+	mNumbers = 0;
+	mVolumeFont = 0;
+	mPitchFont = 0;
 
-	if ( exist("splashscreen") )
+	if ( exist("splashscreen") && mPrefs->displaySplash() )
 		showSplash();
 
 	if ( (file != mCurrentWinshadeModeSkin) && (file != mCurrentDockModeSkin) )
@@ -212,46 +212,30 @@ void KJLoader::loadSkin(const QString &file)
 		{
 			// set path to dockmode rc-file (its not always skinname.dck)
 			mCurrentDockModeSkin = file.left(file.findRev("/")+1) + (item("dockmodercfile")[1]);
-//			kdDebug(66666) << " dock: '" << mCurrentDockModeSkin.latin1() << "'" << endl;
-			mDockPosition = item("dockmodeposition")[1].toInt();
+			mDockPosition  = item("dockmodeposition")[1].toInt();
 			mDockPositionX = item("dockmodepositionxy")[1].toInt();
 			mDockPositionY = item("dockmodepositionxy")[2].toInt();
 		}
-		else
-		{
+		else	// NO DockMode
 			mCurrentDockModeSkin="";
-//			kdDebug(66666) << " No dockmode available" << endl;
-		}
 
 		if ( exist("winshademodercfile") )
-		{
 			mCurrentWinshadeModeSkin = file.left(file.findRev("/")+1) + (item("winshademodercfile")[1]);
-//			kdDebug(66666) << " winshade: '" << mCurrentWinshadeModeSkin.latin1() << "'" << endl;
-		}
-		else
-		{
+		else	// no WinshadeMode
 			mCurrentWinshadeModeSkin="";
-//			kdDebug(66666) << " No winshademode available" << endl;
-		}
 	}
 
 	// Font-loading
 	if ( exist("fontimage") )
 		mText = new KJFont("font", this);
-	else
-		mText = 0;
 
 	if ( exist("timefontimage") )
 		mNumbers = new KJFont("timefont", this);
-	else
-		mNumbers = 0;
 
 	if (exist("volumefontimage"))
 		mVolumeFont = new KJFont("volumefont", this);
-	else
-		mVolumeFont = 0;
 
-	// our skin-background
+	// our skin-background, There has to be one so no check with exist()
 	subwidgets.append( new KJBackground(this) );
 
 	if ( exist("pitchtext") )
@@ -266,8 +250,7 @@ void KJLoader::loadSkin(const QString &file)
 			kdDebug(66666) << "no pitchfont but pitchtext!" << endl;
 			kdDebug(66666) << "replacing pitchfont with timefont" << endl;
 		}
-//		kdDebug(66666) << "added KJPitchText" << endl;
-		subwidgets.append(pitchText=new KJPitchText(item("pitchtext"), this));
+		subwidgets.append( pitchText=new KJPitchText(item("pitchtext"), this) );
 	}
 
 	if (exist("volumetext"))
@@ -287,10 +270,10 @@ void KJLoader::loadSkin(const QString &file)
 			subwidgets.append(b=new KJVolumeBar(item("volumecontrolbutton"), this));
 			b->setText(volumeText);
 		}
-		else
+/*		else
 		{
 			kdDebug(66666) << "unknown volumecontrol: " << item("volumecontroltype")[1].latin1() << endl;
-		}
+		} */
 	}
 	else
 	{
@@ -312,10 +295,10 @@ void KJLoader::loadSkin(const QString &file)
 			subwidgets.append(b=new KJVolumeBar(item("volumecontrolbutton"), this));
 			b->setText(volumeText);
 		}
-		else
+/*		else
 		{
 			kdDebug(66666) << " no volumecontrol" << endl;
-		}
+		} */
 	}
 
 	if (exist("pitchcontrolbutton") &&
@@ -349,10 +332,15 @@ void KJLoader::loadSkin(const QString &file)
 	if (exist("mp3timewindow"))
 		subwidgets.append(new KJTime(item("mp3timewindow"), this));
 
+	if (exist("mp3kbpswindow"))
+		subwidgets.append(new KJFileInfo(item("mp3kbpswindow"), this));
+
+	if (exist("mp3khzwindow"))
+		subwidgets.append(new KJFileInfo(item("mp3khzwindow"), this));
+
 	if (exist("analyzerwindow"))
 	{
-		KGlobal::config()->setGroup("KJofol-Skins");
-		int vistype = KGlobal::config()->readNumEntry("AnalyzerType", KJVisScope::FFT );
+		int vistype = mPrefs->visType();
 		switch ( vistype )
 		{
 			case KJVisScope::Null:
@@ -382,7 +370,7 @@ void KJLoader::loadSkin(const QString &file)
 			!d.startsWith("playlistwindow") && // don't add buttons that belong to the playlistwindow
 			d != "pitchcontrolbutton" &&  // both already handled above as they aren't buttons but sliders
 			d != "volumecontrolbutton" &&
-			i.count() >= 7)
+			i.count() >= 7 )
 		{
 			subwidgets.append(new KJButton(*(*i), this));
 		}
@@ -415,24 +403,33 @@ void KJLoader::unloadSkin()
 //	kdDebug(66666) << " freeing subwidgets" << endl;
 	subwidgets.clear();
 
+	// This is special because mPitchfont can also point to mNumbers
+	// as some skins use the NumberFont for pitchtext
+	if ( mPitchFont && mPitchFont != mNumbers )
+	{
+		kdDebug(66666) << " freeing mPitchFont" << endl;
+		delete mPitchFont;
+	}
+
 	if ( mText )
 	{
-//		kdDebug(66666) << " freeing mText" << endl;
+		kdDebug(66666) << " freeing mText" << endl;
 		delete mText;
 	}
 
 	if ( mNumbers )
 	{
-//		kdDebug(66666) << " freeing mNumbers" << endl;
+		kdDebug(66666) << " freeing mNumbers" << endl;
 		delete mNumbers;
 	}
 
 	if ( mVolumeFont )
 	{
-//		kdDebug(66666) << " freeing mVolumeFont" << endl;
+		kdDebug(66666) << " freeing mVolumeFont" << endl;
 		delete mVolumeFont;
 	}
 
+
 //	kdDebug(66666) << "</KJLoader::unloadSkin()>" << endl;
 }
 
@@ -650,9 +647,9 @@ KJLoader::~KJLoader()
 {
 //	kdDebug(66666) << "KJLoader::~KJLoader()" << endl;
 //	kdDebug(66666) << "freeing mHelpMenu" << endl;
-	delete mHelpMenu;
+//	delete mHelpMenu;
 //	kdDebug(66666) << "freeing mTooltips" << endl;
-	delete mTooltips;
+//	delete mTooltips;
 //	kdDebug(66666) << "freeing mWin" << endl;
 	delete mWin;
 }
@@ -711,7 +708,7 @@ void KJLoader::mousePressEvent(QMouseEvent *e)
 	}
 }
 
-void KJLoader::mouseReleaseEvent(QMouseEvent *e)
+void KJLoader::mouseReleaseEvent(QMouseEvent */*e*/)
 {
 //	kdDebug(66666) << "KJLoader::mouseReleaseEvent(QMouseEvent *e)" << endl;
 
@@ -755,14 +752,14 @@ void KJLoader::playlistHidden(void)
 		i->playlistHidden();
 }
 
-/*
+
 void KJLoader::readConfig()
 {
 	kdDebug(66666) << "KJLoader::readConfig()" << endl;
 	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
 		i->readConfig();
 }
-*/
+
 
 void KJLoader::showSplash(void)
 {
@@ -789,6 +786,7 @@ void KJLoader::showSplash(void)
 
 	splashScreen->setFixedSize(sh);
 	splashScreen->show();
+	napp->processEvents(); // we want this one time to get the splash actually displayed ASAP
 
 	QTimer::singleShot(3000, this, SLOT(hideSplash()) );
 }
@@ -799,4 +797,3 @@ void KJLoader::hideSplash(void)
 	delete splashScreen;
 }
 
-#include "kjloader.moc"
