@@ -1,7 +1,9 @@
 #ifndef KJPREFS_H
 #define KJPREFS_H
 
-#include "kjprefswidget.h"
+//#include "kjprefswidget.h"
+#include "kjskinselectorwidget.h"
+#include "kjguisettingswidget.h"
 
 // system includes
 #include <qwidget.h>
@@ -16,12 +18,14 @@ class QGridLayout;
 class QComboBox;
 class QLabel;
 class QPushButton;
+class QTabWidget;
+class KConfig;
 class KJLoader;
 
-class KJPrefsWidget;
+static QString expand(QString s);
 
 class KJPrefs : public CModule
-{ 
+{
 Q_OBJECT
 public:
 	KJPrefs(QObject* parent);
@@ -32,6 +36,25 @@ public:
 	// Rebuild the Skinlist
 	virtual void reopen();
 
+	QString skin( void ) const;
+
+	int minimumPitch( void ) const;
+	int maximumPitch( void ) const;
+
+	int visTimerValue ( void ) const;
+
+	int titleMovingUpdates ( void ) const;
+	float titleMovingDistance ( void ) const;
+
+	int visType ( void ) const;
+	void setVisType ( int vis );
+
+	bool timeCountMode( void ) const;
+	void setTimeCountMode( bool mode );
+
+	bool displayTooltips( void ) const;
+	bool displaySplash( void ) const;
+
 public slots:
 	// Installs a skin defined by the URL in mSkinRequester
 	void installNewSkin( void );
@@ -47,12 +70,16 @@ public slots:
 	void slotResult(KIO::Job *job);
 
 signals:
-//	void configChanged();
+	void configChanged();
 
 private:
-	QPixmap mPixmap;
-	// Dialog-Widget
-	KJPrefsWidget *prefsWidget;
+	QPixmap mPixmap; // preview Pixmap
+	KConfig *cfg;
+
+	// Dialog-Widgets
+	QTabWidget *mTabWidget;
+	KJSkinselector *mSkinselectorWidget;
+	KJGuiSettings *mGuiSettingsWidget;
 };
 
 /**
