@@ -11,6 +11,7 @@ public:
 	KJVisScope(KJLoader *parent) : KJWidget(parent) {}
 	enum Visuals { Null=0, FFT, Mono };
 	void swapScope(Visuals newOne);
+//	virtual void readConfig();
 };
 
 // dummy-scope displaying nothing
@@ -20,6 +21,8 @@ public:
 	KJNullScope(const QStringList &, KJLoader *parent);
 	virtual void paint(QPainter *p, const QRect &);
 	virtual bool mousePress(const QPoint&);
+	virtual void mouseRelease(const QPoint &, bool in);
+	virtual void readConfig(void);
 
 private:
 	KPixmap *mBack;
@@ -35,6 +38,8 @@ public:
 	virtual void scopeEvent(float *d, int size);
 
 	virtual bool mousePress(const QPoint&);
+	virtual void mouseRelease(const QPoint &, bool in);
+	virtual void readConfig(void);
 
 private:
 	QColor mColor;
@@ -42,6 +47,7 @@ private:
 	KPixmap *mBack;
 	KPixmap *mAnalyzer;
 	int mMultiples;
+	int mTimerValue;
 };
 
 // oscilloscope showing waveform
@@ -53,15 +59,19 @@ public:
 	virtual void scopeEvent(float *d, int size);
 
 	virtual bool mousePress(const QPoint&);
+	virtual void mouseRelease(const QPoint &, bool in);
+	virtual void readConfig(void);
 
 private:
 	QColor mColor;
+	KPixmap *mGradient;
 	KPixmap *mBack;
 	KPixmap *mOsci;
 	int mMultiples;
 	int mWidth;
 	int mHeight;
 	unsigned int blurnum;
+	int mTimerValue;
 };
 
 #endif
