@@ -152,7 +152,7 @@ void Editor::saveControl(KFileMetaInfo& meta_info, const MetaWidget &meta_widget
 
         if (info->groupInfo(group)->itemInfo(meta_widget.key)->attributes() & KFileMimeTypeInfo::Addable) {
             kdDebug() << "Adding key " << meta_widget.key << endl;
-            if (!meta_info.group(group).addItem(meta_widget.key).isValid());
+            if (!meta_info.group(group).addItem(meta_widget.key).isValid())
                 kdWarning() << "Adding key \"" << meta_widget.key << "\" failed!" << endl;
         }
      }
