@@ -19,8 +19,8 @@ Finder::Finder(QWidget *parent) : KDialogBase(parent, 0, false, i18n("Find"), Cl
 
 	mText->setFocus();
 
-	mRegexp=new QCheckBox(i18n("&Regular Expression"), mainWidget);
-	mBackwards=new QCheckBox(i18n("Find &Backwards"), mainWidget);
+	mRegexp=new QCheckBox(i18n("&Regular expression"), mainWidget);
+	mBackwards=new QCheckBox(i18n("Find &backwards"), mainWidget);
 
 	layout->addMultiCellWidget(mText, 0, 0, 0, 1);
 	layout->addWidget(mRegexp, 1, 0);
