@@ -125,32 +125,7 @@ SafeListViewItem::SafeListViewItem(QListView *parent, QListViewItem *after, cons
 
 SafeListViewItem::~SafeListViewItem()
 {
-	removed=true;
-	if (napp->player()->current()==this && !itemAbove() && !itemBelow())
-	{
-		napp->player()->stop();
-		SPL->setCurrent(0);
-	}
-	else if (napp->player()->current()==this)
-	{
-		SPL->setCurrent(0);
-		if (!SPL->exiting())
-			napp->player()->forward();
-	}
-
-	if (SPL->nextItem==this)
-		SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
-	if (SPL->currentItem==this) // just optimizing for least unreadably
-		SPL->setCurrent(0), SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
-	if (SPL->previousItem==this)
-		SPL->setPrevious(static_cast<SafeListViewItem*>(itemAbove()));
-
-	PlaylistItemData::removed();
-}
-
-void SafeListViewItem::removeMe()
-{
-	delete this;
+	remove();
 }
 
 QString SafeListViewItem::file() const
@@ -339,7 +314,31 @@ void SafeListViewItem::stateChange(bool s)
 
 void SafeListViewItem::remove()
 {
-	delete this;
+	removed=true;
+	if (napp->player()->current()==this && !itemAbove() && !itemBelow())
+	{
+		napp->player()->stop();
+		SPL->setCurrent(0);
+		napp->player()->playCurrent();
+	}
+	else if (napp->player()->current()==this)
+	{
+		SPL->setCurrent(0);
+		napp->player()->playCurrent();
+		if (!SPL->exiting())
+			napp->player()->forward();
+	}
+
+	if (SPL->nextItem==this)
+		SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
+	if (SPL->currentItem==this) // just optimizing for least unreadably
+		SPL->setCurrent(0), SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
+	if (SPL->previousItem==this)
+		SPL->setPrevious(static_cast<SafeListViewItem*>(itemAbove()));
+
+	if (listView())
+		listView()->takeItem(this);
+	PlaylistItemData::removed();
 }
 
 List::List(View *parent)
@@ -874,9 +873,9 @@ void List::clear()
 
 void View::deleteSelected()
 {
-	QList<QListViewItem> items(list->selectedItems());
-	for (QListIterator<QListViewItem> it(items); it.current(); ++it)
-		static_cast<SafeListViewItem*>(*it)->removeMe();
+	QPtrList<QListViewItem> items(list->selectedItems());
+	for (QPtrListIterator<QListViewItem> it(items); it.current(); ++it)
+		static_cast<SafeListViewItem*>(*it)->remove();
 
 	setModified(true);
 }
