@@ -7,7 +7,7 @@
 extern "C" {
     Plugin *create_plugin() {
 	WaSkin *new_skin = new WaSkin();
-	new WinSkinConfig(new_skin, new_skin);
+	new WinSkinConfig(new_skin, new_skin->skinManager());
 	return new_skin;
     }
 }
