@@ -17,7 +17,6 @@
 VISQueue::VISQueue(int elements) {
   this->elements=elements;
   int i;
-  visArrayQueue=new (std::vector<float>*[elements]);
   for(i=0;i<elements;i++) {
     visArrayQueue[i]=new std::vector<float>;
   }
@@ -30,7 +29,6 @@ VISQueue::~VISQueue() {
   for(i=0;i<elements;i++) {
     delete visArrayQueue[i];
   }
-  delete visArrayQueue;
 }
 
 std::vector<float>* VISQueue::getElement(int i) {
