@@ -1,6 +1,6 @@
 /*
    This file is part of KDE/aRts (Noatun) - xine integration
-   Copyright (C) 2002 Ewald Snel <ewald@rambo.its.tudelft.nl>
+   Copyright (C) 2002-2003 Ewald Snel <ewald@rambo.its.tudelft.nl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,6 +11,10 @@
 #ifndef __AUDIO_FIFO_OUT_H
 #define __AUDIO_FIFO_OUT_H
 
+#ifdef HAVE_XINE_1
+#include <xine.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -23,16 +27,22 @@ typedef struct
 } xine_arts_audio;
 
 
-ao_driver_t *init_audio_out_plugin( config_values_t *config, xine_arts_audio *audio );
+#ifdef HAVE_XINE_1
+xine_audio_port_t *init_audio_out_plugin( xine_t *xine, xine_arts_audio *audio,
+					  void **ao_driver );
+#else
+ao_driver_t *init_audio_out_plugin( xine_t *xine, xine_arts_audio *audio,
+				    void **ao_driver );
+#endif
 
 int ao_fifo_arts_delay();
 
-unsigned long ao_fifo_read( ao_driver_t *this_gen, unsigned char **buffer,
+unsigned long ao_fifo_read( void *ao_driver, unsigned char **buffer,
 			    unsigned long samples );
 
-void ao_fifo_flush( ao_driver_t *ao, unsigned long samples );
+void ao_fifo_flush( void *ao_driver, unsigned long samples );
 
-void ao_fifo_wait_close( ao_driver_t *this_gen );
+void ao_fifo_clear( void *ao_driver, int clear );
 
 #ifdef __cplusplus
 }
